# REQ03 - Requirements Management

Quản lý, theo dõi và kiểm soát thay đổi yêu cầu trong suốt vòng đời dự án.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Requirements Traceability](REQ03-BP01-Requirements-Traceability.md) | Theo dõi yêu cầu từ nguồn đến implementation |
| BP02 | [Change Management](REQ03-BP02-Change-Management.md) | Quy trình quản lý thay đổi yêu cầu |

## Tham khảo

- IEEE 830 - Requirements Management
- CMMI - Requirements Management Process Area
- PMI - Requirements Change Control
